@@ -1,11 +1,12 @@
 from swap.api.clients import UBLClient
 from swap.api.parsers import InputDatasetsResponseParser
 from swap.common.config import Settings
+import json
 
 client = UBLClient()
 
 class Dataset:
-    def __init__(self, input_dataset, metadata=""):
+    def __init__(self, input_dataset, metadata=None):
         self.name = input_dataset.name
         self.input_dataset = input_dataset
         self.dataset_type = 'GCS'
@@ -15,12 +16,13 @@ class Dataset:
     def to_dict(self):
         dataset_dict = {}
         dataset_dict['data_uri'] = self.url
-        dataset_dict['metadata'] = self.metadata
+        dataset_dict['metadata'] = json.dumps(self.metadata)
+        dataset_dict['metadata'] = dataset_dict['metadata'].replace('"', "'")
         return dataset_dict
 
 
 class CDFDataset:
-    def __init__(self, dataset_id, survey_id="N/A", metadata=""):
+    def __init__(self, dataset_id, survey_id="N/A", metadata=None):
         if survey_id != "N/A":
             self.url = f'cdf://{survey_id}/{dataset_id}'
         else:
@@ -34,7 +36,8 @@ class CDFDataset:
     def to_dict(self):
         dataset_dict = {}
         dataset_dict['data_uri'] = self.url
-        dataset_dict['metadata'] = self.metadata
+        dataset_dict['metadata'] = json.dumps(self.metadata)
+        dataset_dict['metadata'] = dataset_dict['metadata'].replace('"', "'")
         return dataset_dict
 
 
